@@ -13,14 +13,19 @@
 /*
  * irc_version is what $J returns, its the common-name for the version.
  */
-const char irc_version[] = "EPIC4-0.9.13";
-const char useful_info[] = "epic4 0 9 13";
+const char irc_version[] = "EPIC4-0.9.14";
+const char useful_info[] = "epic4 0 9 14";
 
 /*
  * internal_version is what $V returns, its the integer-id for the
  * version, and corresponds to the date of release, YYYYMMDD.
  */ 
-const char internal_version[] = "20001130";
+const char internal_version[] = "20001208";
+
+/*
+ * In theory, this number is incremented for every commit.
+ */
+const unsigned long	commit_id = 9;
 
 /*
  * As a way to poke fun at the current rage of naming releases after
@@ -28,7 +33,7 @@ const char internal_version[] = "20001130";
  * reality, I have decided to start doing that with EPIC.  These names
  * are intentionally and maliciously silly.  Complaints will be ignored.
  */
-const char ridiculous_version_name[] = "Mollify";
+const char ridiculous_version_name[] = "Perniscious";
 
 #define __need_putchar_x__
 #include "status.h"
